=== modified file 'bzrlib/remote.py'
--- bzrlib/remote.py	2011-11-25 18:45:53 +0000
+++ bzrlib/remote.py	2011-11-28 03:03:27 +0000
@@ -24,6 +24,7 @@
     controldir,
     debug,
     errors,
+    gpg,
     graph,
     lock,
     lockdir,
@@ -32,6 +33,7 @@
     revision as _mod_revision,
     static_tuple,
     symbol_versioning,
+    testament as _mod_testament,
     urlutils,
     vf_repository,
     )
@@ -2177,8 +2179,9 @@
 
     @needs_write_lock
     def sign_revision(self, revision_id, gpg_strategy):
-        self._ensure_real()
-        return self._real_repository.sign_revision(revision_id, gpg_strategy)
+        testament = _mod_testament.Testament.from_revision(self, revision_id)
+        plaintext = testament.as_short_text()
+        self.store_revision_signature(gpg_strategy, plaintext, revision_id)
 
     @property
     def texts(self):
@@ -2240,10 +2243,16 @@
             raise SmartProtocolError('unexpected response code %s' % (response,))
         return (response[0] == 'yes')
 
+    @needs_read_lock
     def verify_revision_signature(self, revision_id, gpg_strategy):
-        self._ensure_real()
-        return self._real_repository.verify_revision_signature(
-            revision_id, gpg_strategy)
+        if not self.has_signature_for_revision_id(revision_id):
+            return gpg.SIGNATURE_NOT_SIGNED, None
+        signature = self.get_signature_text(revision_id)
+
+        testament = _mod_testament.Testament.from_revision(self, revision_id)
+        plaintext = testament.as_short_text()
+
+        return gpg_strategy.verify(signature, plaintext)
 
     def item_keys_introduced_by(self, revision_ids, _files_pb=None):
         self._ensure_real()

